@@ -9,8 +9,11 @@ our $VERSION = 0.01;
 our @ISA     = qw(Exporter);
 our @EXPORT  = qw(
                   for_all_hosts
+                  get_age_group
+                  get_age_groups
                   get_debian_edu_profile
                   get_debian_edu_ver
+                  get_debian_ver
                   get_default_route
                   get_dns_address
                   get_filepath_current
@@ -249,6 +252,19 @@ sub get_debian_edu_ver {
     }
 }
 
+sub get_debian_ver {
+    my $hostid = shift;
+    my $path = get_filepath_current($hostid, "/debian/debian_version");
+    if (open (my $fh, $path)) {
+        my $version = <$fh>;
+        chomp $version;
+        close($fh);
+        return $version;
+    } else {
+        return undef;
+    }
+}
+
 sub get_hardware_info {
     my $hostid = shift;
     my $path = get_filepath_current($hostid, "/system/dmidecode");
@@ -267,6 +283,22 @@ sub get_hardware_info {
         }
         close(FILE);
 
+        # Avoid returning bogus vendor and model
+        undef $vendor if (defined $vendor &&
+                          (
+                           "Not Specified" eq $vendor
+                           || "System Manufaturer" eq $vendor
+                           || "System manufaturer" eq $vendor
+                           || "To Be Filled By O.E.M. by More String" eq $vendor
+                          ));
+        undef $model if (defined $model &&
+                         (
+                          "Not Specified" eq $model
+                          || "System Name" eq $model
+                          || "System Product Name" eq $model
+                          || "To Be Filled By O.E.M. To Be Filled By O.E.M." eq $model
+                         ));
+
         # Append version string to get for example the thinkpad model
         # name, but ignore bogus entries.
         $model = "$model $version" if ($version
@@ -326,6 +358,33 @@ sub for_all_hosts {
     return $count;
 }
 
+sub get_age_groups {
+    return (
+        0 => '>0 days',
+        3 => '>3 days',
+        7 => '>one week',
+        14 => '>14 days',
+        30 => '>30 days',
+        90 => '>90 days',
+        120 => '>120 days',
+        180 => '>180 days',
+        );
+}
+sub get_age_group {
+    my $hostid = shift;
+    my %agegroups = get_age_groups();
+    my $topdir = get_filepath_current($hostid, "/");
+    my $age = (time() - (stat($topdir))[9]) / (60 * 60 * 24);
+
+    my $thisgroup;
+    for my $group (sort { $a <=> $b; } keys %agegroups) {
+        if ($age > $group) {
+            $thisgroup = $group;
+        }
+    }
+    return $thisgroup;
+}
+
 1;
 
 ########################################################################
